@@ -195,12 +195,7 @@ void OCLTypeToSPIRVBase::adaptArgumentsBySamplerUse(Module &M) {
     StringRef DemangledName;
     if (!oclIsBuiltin(MangledName, DemangledName, false))
       continue;
-    // Note: kSPIRVName::ConvertHandleToSampledImageINTEL contains
-    // kSPIRVName::SampledImage as a substring, but we still want to continue in
-    // this case.
-    if (DemangledName.find(kSPIRVName::SampledImage) == std::string::npos ||
-        DemangledName.find(kSPIRVName::ConvertHandleToSampledImageINTEL) !=
-            std::string::npos)
+    if (DemangledName.find(kSPIRVName::SampledImage) == std::string::npos)
       continue;
 
     TraceArg(&F, 1);
