@@ -619,12 +619,6 @@ void SPIRVTypeScavenger::typeGlobalValue(GlobalValue &GV, Constant *Init) {
       auto It = DeducedTypes.find(C);
       if (It != DeducedTypes.end())
         return It->second;
-    } else if (auto *GEP = dyn_cast<GEPOperator>(C)) {
-      auto *ResultTy =
-          TypedPointerType::get(GEP->getResultElementType(),
-                                GEP->getType()->getPointerAddressSpace());
-      DeducedTypes[C] = ResultTy;
-      return ResultTy;
     }
 
     return getUnknownTyped(C->getType());
@@ -742,8 +736,7 @@ void SPIRVTypeScavenger::deduceFunctionType(Function &F) {
         for (Argument *Arg : PointerArgs) {
           if (auto *Ty =
                   dyn_cast<TypedPointerType>(ParamTypes[Arg->getArgNo()]))
-            if (!Arg->hasAttribute(Attribute::StructRet))
-              TypeArgument(Arg, Ty);
+            TypeArgument(Arg, Ty);
         }
       }
     }
