@@ -94,24 +94,6 @@ void removeFnAttr(CallInst *Call, Attribute::AttrKind Attr) {
   Call->removeFnAttr(Attr);
 }
 
-Value *extendVector(Value *V, FixedVectorType *NewType,
-                    IRBuilderBase &Builder) {
-  unsigned OldSize = cast<FixedVectorType>(V->getType())->getNumElements();
-  unsigned NewSize = NewType->getNumElements();
-  assert(OldSize < NewSize);
-  std::vector<Constant *> Components;
-  IntegerType *Int32Ty = Builder.getInt32Ty();
-  for (unsigned I = 0; I < NewSize; I++) {
-    if (I < OldSize)
-      Components.push_back(ConstantInt::get(Int32Ty, I));
-    else
-      Components.push_back(PoisonValue::get(Int32Ty));
-  }
-
-  return Builder.CreateShuffleVector(V, PoisonValue::get(V->getType()),
-                                     ConstantVector::get(Components), "vecext");
-}
-
 void saveLLVMModule(Module *M, const std::string &OutputFile) {
   std::error_code EC;
   ToolOutputFile Out(OutputFile.c_str(), EC, sys::fs::OF_None);
@@ -185,7 +167,7 @@ StructType *getOrCreateOpaqueStructType(Module *M, StringRef Name) {
 }
 
 void getFunctionTypeParameterTypes(llvm::FunctionType *FT,
-                                   SmallVector<Type *> &ArgTys) {
+                                   std::vector<Type *> &ArgTys) {
   for (auto I = FT->param_begin(), E = FT->param_end(); I != E; ++I) {
     ArgTys.push_back(*I);
   }
@@ -637,21 +619,6 @@ static Type *parsePrimitiveType(LLVMContext &Ctx, StringRef Name) {
 
 } // namespace SPIRV
 
-namespace {
-
-// Return the value for when the dimension index of a builtin is out of range.
-uint64_t getBuiltinOutOfRangeValue(StringRef VarName) {
-  assert(VarName.starts_with("__spirv_BuiltIn"));
-  return StringSwitch<uint64_t>(VarName)
-      .EndsWith("GlobalSize", 1)
-      .EndsWith("NumWorkgroups", 1)
-      .EndsWith("WorkgroupSize", 1)
-      .EndsWith("EnqueuedWorkgroupSize", 1)
-      .Default(0);
-}
-
-} // anonymous namespace
-
 // The demangler node hierarchy doesn't use LLVM's RTTI helper functions (as it
 // also needs to live in libcxxabi). By specializing this implementation here,
 // we can add support for these functions.
@@ -1343,8 +1310,6 @@ static SPIR::RefParamType transTypeDesc(Type *Ty,
     return SPIR::RefParamType(new SPIR::PrimitiveType(SPIR::PRIMITIVE_FLOAT));
   if (Ty->isDoubleTy())
     return SPIR::RefParamType(new SPIR::PrimitiveType(SPIR::PRIMITIVE_DOUBLE));
-  if (Ty->isBFloatTy())
-    return SPIR::RefParamType(new SPIR::PrimitiveType(SPIR::PRIMITIVE_BFLOAT));
   if (auto *VecTy = dyn_cast<FixedVectorType>(Ty)) {
     return SPIR::RefParamType(new SPIR::VectorType(
         transTypeDesc(VecTy->getElementType(), Info), VecTy->getNumElements()));
@@ -1613,9 +1578,6 @@ Type *getLLVMTypeForSPIRVImageSampledTypePostfix(StringRef Postfix,
   if (Postfix == kSPIRVImageSampledTypeName::Int ||
       Postfix == kSPIRVImageSampledTypeName::UInt)
     return Type::getInt32Ty(Ctx);
-  if (Postfix == kSPIRVImageSampledTypeName::Long ||
-      Postfix == kSPIRVImageSampledTypeName::ULong)
-    return Type::getInt64Ty(Ctx);
   llvm_unreachable("Invalid sampled type postfix");
   return nullptr;
 }
@@ -1667,18 +1629,6 @@ std::string getImageBaseTypeName(StringRef Name) {
   return ImageTyName;
 }
 
-size_t getImageOperandsIndex(Op OpCode) {
-  switch (OpCode) {
-  case OpImageRead:
-  case OpImageSampleExplicitLod:
-    return 2;
-  case OpImageWrite:
-    return 3;
-  default:
-    return ~0U;
-  }
-}
-
 SPIRVTypeImageDescriptor getImageDescriptor(Type *Ty) {
   if (auto *TET = dyn_cast_or_null<TargetExtType>(Ty)) {
     auto IntParams = TET->int_params();
@@ -2039,20 +1989,19 @@ bool isSPIRVBuiltinVariable(GlobalVariable *GV,
 /// are accumulated in the AccumulatedOffset parameter, which will eventually be
 /// used to figure out which index of a variable is being used.
 static void replaceUsesOfBuiltinVar(Value *V, const APInt &AccumulatedOffset,
-                                    Function *ReplacementFunc,
-                                    GlobalVariable *GV) {
+                                    Function *ReplacementFunc) {
   const DataLayout &DL = ReplacementFunc->getParent()->getDataLayout();
   SmallVector<Instruction *, 4> InstsToRemove;
   for (User *U : V->users()) {
     if (auto *Cast = dyn_cast<CastInst>(U)) {
-      replaceUsesOfBuiltinVar(Cast, AccumulatedOffset, ReplacementFunc, GV);
+      replaceUsesOfBuiltinVar(Cast, AccumulatedOffset, ReplacementFunc);
       InstsToRemove.push_back(Cast);
     } else if (auto *GEP = dyn_cast<GetElementPtrInst>(U)) {
       APInt NewOffset = AccumulatedOffset.sextOrTrunc(
           DL.getIndexSizeInBits(GEP->getPointerAddressSpace()));
       if (!GEP->accumulateConstantOffset(DL, NewOffset))
         llvm_unreachable("Illegal GEP of a SPIR-V builtin variable");
-      replaceUsesOfBuiltinVar(GEP, NewOffset, ReplacementFunc, GV);
+      replaceUsesOfBuiltinVar(GEP, NewOffset, ReplacementFunc);
       InstsToRemove.push_back(GEP);
     } else if (auto *Load = dyn_cast<LoadInst>(U)) {
       // Figure out which index the accumulated offset corresponds to. If we
@@ -2075,12 +2024,7 @@ static void replaceUsesOfBuiltinVar(Value *V, const APInt &AccumulatedOffset,
       } else {
         // The function has an index parameter.
         if (auto *VecTy = dyn_cast<FixedVectorType>(Load->getType())) {
-          // Reconstruct the original global variable vector because
-          // the load type may not match.
-          // global <3 x i64>, load <6 x i32>
-          VecTy = cast<FixedVectorType>(GV->getValueType());
-          if (!Index.isZero() || DL.getTypeSizeInBits(VecTy) !=
-                                     DL.getTypeSizeInBits(Load->getType()))
+          if (!Index.isZero())
             llvm_unreachable("Illegal use of a SPIR-V builtin variable");
           Replacement = UndefValue::get(VecTy);
           for (unsigned I = 0; I < VecTy->getNumElements(); I++) {
@@ -2090,19 +2034,6 @@ static void replaceUsesOfBuiltinVar(Value *V, const APInt &AccumulatedOffset,
                     Builder.CreateCall(ReplacementFunc, {Builder.getInt32(I)})),
                 Builder.getInt32(I));
           }
-          // Insert a bitcast from the reconstructed vector to the load vector
-          // type in case they are different.
-          // Input:
-          // %1 = load <6 x i32>, ptr addrspace(1) %0, align 32
-          // %2 = extractelement <6 x i32> %1, i32 0
-          // %3 = add i32 5, %2
-          // Modified:
-          // < reconstruct global vector elements 0 and 1 >
-          // %2 = insertelement <3 x i64> %0, i64 %1, i32 2
-          // %3 = bitcast <3 x i64> %2 to <6 x i32>
-          // %4 = extractelement <6 x i32> %3, i32 0
-          // %5 = add i32 5, %4
-          Replacement = Builder.CreateBitCast(Replacement, Load->getType());
         } else if (Load->getType() == ScalarTy) {
           Replacement = setAttrByCalledFunc(Builder.CreateCall(
               ReplacementFunc, {Builder.getInt32(Index.getZExtValue())}));
@@ -2156,7 +2087,7 @@ bool lowerBuiltinVariableToCall(GlobalVariable *GV,
     Func->setDoesNotAccessMemory();
   }
 
-  replaceUsesOfBuiltinVar(GV, APInt(64, 0), Func, GV);
+  replaceUsesOfBuiltinVar(GV, APInt(64, 0), Func);
   return true;
 }
 
@@ -2209,50 +2140,22 @@ bool lowerBuiltinCallsToVariables(Module *M) {
     bool IsVec = F.getFunctionType()->getNumParams() > 0;
     Type *GVType =
         IsVec ? FixedVectorType::get(F.getReturnType(), 3) : F.getReturnType();
-    GlobalVariable *BV = nullptr;
-    // Consider the following LLVM IR:
-    // @__spirv_BuiltInLocalInvocationId = <Global constant>
-    // .....
-    // define spir_kernel void @kernel1(....) {
-    //   %3 = tail call i64 @_Z12get_local_idj(i32 0)
-    //   .....
-    //   return void
-    // }
-    // During the OCLToSPIRV pass, the opencl call will get lowered to
-    // yet another global variable with the name
-    // '@__spirv_BuiltInLocalInvocationId'. In such a case, we would want to
-    // create only a single global variable with this name.
-    if (GlobalVariable *GV = M->getGlobalVariable(BuiltinVarName))
-      BV = GV;
-    else
-      BV = new GlobalVariable(*M, GVType, /*isConstant=*/true,
-                              GlobalValue::ExternalLinkage, nullptr,
-                              BuiltinVarName, 0, GlobalVariable::NotThreadLocal,
-                              SPIRAS_Input);
+    auto *BV = new GlobalVariable(
+        *M, GVType, /*isConstant=*/true, GlobalValue::ExternalLinkage, nullptr,
+        BuiltinVarName, 0, GlobalVariable::NotThreadLocal, SPIRAS_Input);
     for (auto *U : F.users()) {
       auto *CI = dyn_cast<CallInst>(U);
       assert(CI && "invalid instruction");
-      IRBuilder<> Builder(CI);
-      Value *NewValue = Builder.CreateLoad(GVType, BV);
+      const DebugLoc &DLoc = CI->getDebugLoc();
+      Instruction *NewValue = new LoadInst(GVType, BV, "", CI);
+      if (DLoc)
+        NewValue->setDebugLoc(DLoc);
       LLVM_DEBUG(dbgs() << "Transform: " << *CI << " => " << *NewValue << '\n');
       if (IsVec) {
-        auto *GVVecTy = cast<FixedVectorType>(GVType);
-        ConstantInt *Bound = Builder.getInt32(GVVecTy->getNumElements());
-        // Create a select on the index first, to avoid undefined behaviour
-        // due to exceeding the vector size by the extractelement.
-        Value *IndexCmp = Builder.CreateICmpULT(CI->getArgOperand(0), Bound);
-        Constant *ZeroIndex =
-            ConstantInt::get(CI->getArgOperand(0)->getType(), 0);
-        Value *ExtractIndex =
-            Builder.CreateSelect(IndexCmp, CI->getArgOperand(0), ZeroIndex);
-
-        // Extract from builtin variable.
-        NewValue = Builder.CreateExtractElement(NewValue, ExtractIndex);
-
-        // Clamp to out-of-range value.
-        Constant *OutOfRangeVal = ConstantInt::get(
-            F.getReturnType(), getBuiltinOutOfRangeValue(BuiltinVarName));
-        NewValue = Builder.CreateSelect(IndexCmp, NewValue, OutOfRangeVal);
+        NewValue =
+            ExtractElementInst::Create(NewValue, CI->getArgOperand(0), "", CI);
+        if (DLoc)
+          NewValue->setDebugLoc(DLoc);
         LLVM_DEBUG(dbgs() << *NewValue << '\n');
       }
       NewValue->takeName(CI);
@@ -2289,24 +2192,11 @@ bool postProcessBuiltinReturningStruct(Function *F) {
   SmallVector<Instruction *, 32> InstToRemove;
   for (auto *U : F->users()) {
     if (auto *CI = dyn_cast<CallInst>(U)) {
-      IRBuilder<> Builder(CI->getParent());
-      Builder.SetInsertPoint(CI);
-      SmallVector<User *> Users(CI->users());
-      Value *A = nullptr;
-      StoreInst *SI = nullptr;
-      for (auto *U : Users) {
-        if ((SI = dyn_cast<StoreInst>(U)) != nullptr) {
-          A = SI->getPointerOperand();
-          InstToRemove.push_back(SI);
-          break;
-        }
-      }
-      if (!A) {
-        A = Builder.CreateAlloca(F->getReturnType());
-      }
-      SmallVector<Type *> ArgTys;
+      auto *ST = cast<StoreInst>(*(CI->user_begin()));
+      std::vector<Type *> ArgTys;
       getFunctionTypeParameterTypes(F->getFunctionType(), ArgTys);
-      ArgTys.insert(ArgTys.begin(), A->getType());
+      ArgTys.insert(ArgTys.begin(),
+                    PointerType::get(F->getReturnType(), SPIRAS_Private));
       auto *NewF =
           getOrCreateFunction(M, Type::getVoidTy(*Context), ArgTys, Name);
       auto SretAttr = Attribute::get(*Context, Attribute::AttrKind::StructRet,
@@ -2314,20 +2204,11 @@ bool postProcessBuiltinReturningStruct(Function *F) {
       NewF->addParamAttr(0, SretAttr);
       NewF->setCallingConv(F->getCallingConv());
       auto Args = getArguments(CI);
-      Args.insert(Args.begin(), A);
-      CallInst *NewCI = Builder.CreateCall(
-          NewF, Args, NewF->getReturnType()->isVoidTy() ? "" : CI->getName());
+      Args.insert(Args.begin(), ST->getPointerOperand());
+      auto *NewCI = CallInst::Create(NewF, Args, CI->getName(), CI);
       NewCI->addParamAttr(0, SretAttr);
       NewCI->setCallingConv(CI->getCallingConv());
-      SmallVector<User *, 32> UsersToReplace;
-      for (auto *U : Users)
-        if (U != SI)
-          UsersToReplace.push_back(U);
-      if (UsersToReplace.size() > 0) {
-        auto *LI = Builder.CreateLoad(F->getReturnType(), A);
-        for (auto *U : UsersToReplace)
-          U->replaceUsesOfWith(CI, LI);
-      }
+      InstToRemove.push_back(ST);
       InstToRemove.push_back(CI);
     }
   }
@@ -2404,13 +2285,12 @@ bool postProcessBuiltinsWithArrayArguments(Module *M, bool IsCpp) {
 namespace {
 class SPIRVFriendlyIRMangleInfo : public BuiltinFuncMangleInfo {
 public:
-  SPIRVFriendlyIRMangleInfo(spv::Op OC, ArrayRef<Type *> ArgTys,
-                            ArrayRef<SPIRVValue *> Ops)
-      : OC(OC), ArgTys(ArgTys), Ops(Ops) {}
+  SPIRVFriendlyIRMangleInfo(spv::Op OC, ArrayRef<Type *> ArgTys)
+      : OC(OC), ArgTys(ArgTys) {}
 
   void init(StringRef UniqUnmangledName) override {
     UnmangledName = UniqUnmangledName.str();
-    switch (static_cast<unsigned>(OC)) {
+    switch (OC) {
     case OpConvertUToF:
     case OpUConvert:
     case OpSatConvertUToS:
@@ -2566,20 +2446,6 @@ public:
     case OpSUDotAccSatKHR:
       addUnsignedArg(1);
       break;
-    case OpImageWrite: {
-      size_t Idx = getImageOperandsIndex(OC);
-      if (Ops.size() > Idx) {
-        auto ImOp = static_cast<SPIRVConstant *>(Ops[Idx])->getZExtIntValue();
-        if (ImOp & ImageOperandsMask::ImageOperandsZeroExtendMask)
-          addUnsignedArg(2);
-      }
-      break;
-    }
-    case internal::OpConvertHandleToImageINTEL:
-    case internal::OpConvertHandleToSamplerINTEL:
-    case internal::OpConvertHandleToSampledImageINTEL:
-      addUnsignedArg(0);
-      break;
     default:;
       // No special handling is needed
     }
@@ -2588,7 +2454,6 @@ public:
 private:
   spv::Op OC;
   ArrayRef<Type *> ArgTys;
-  ArrayRef<SPIRVValue *> Ops;
 };
 class OpenCLStdToSPIRVFriendlyIRMangleInfo : public BuiltinFuncMangleInfo {
 public:
@@ -2658,9 +2523,9 @@ std::string getSPIRVFriendlyIRFunctionName(OCLExtOpKind ExtOpId,
 }
 
 std::string getSPIRVFriendlyIRFunctionName(const std::string &UniqName,
-                                           spv::Op OC, ArrayRef<Type *> ArgTys,
-                                           ArrayRef<SPIRVValue *> Ops) {
-  SPIRVFriendlyIRMangleInfo MangleInfo(OC, ArgTys, Ops);
+                                           spv::Op OC,
+                                           ArrayRef<Type *> ArgTys) {
+  SPIRVFriendlyIRMangleInfo MangleInfo(OC, ArgTys);
   return mangleBuiltin(UniqName, ArgTys, &MangleInfo);
 }
 
