@@ -124,15 +124,9 @@ void SPIRVDecorate::encode(spv_ostream &O) const {
   case DecorationUserSemantic:
     SPIRVDecorateUserSemanticAttr::encodeLiterals(Encoder, Literals);
     break;
-  case internal::DecorationHostAccessINTEL:
-    SPIRVDecorateHostAccessINTELLegacy::encodeLiterals(Encoder, Literals);
-    break;
-  case DecorationHostAccessINTEL:
+  case spv::internal::DecorationHostAccessINTEL:
     SPIRVDecorateHostAccessINTEL::encodeLiterals(Encoder, Literals);
     break;
-  case DecorationInitModeINTEL:
-    SPIRVDecorateInitModeINTEL::encodeLiterals(Encoder, Literals);
-    break;
   default:
     Encoder << Literals;
   }
@@ -159,10 +153,7 @@ void SPIRVDecorate::decode(std::istream &I) {
   case DecorationUserSemantic:
     SPIRVDecorateUserSemanticAttr::decodeLiterals(Decoder, Literals);
     break;
-  case internal::DecorationHostAccessINTEL:
-    SPIRVDecorateHostAccessINTELLegacy::decodeLiterals(Decoder, Literals);
-    break;
-  case DecorationHostAccessINTEL:
+  case spv::internal::DecorationHostAccessINTEL:
     SPIRVDecorateHostAccessINTEL::decodeLiterals(Decoder, Literals);
     break;
   default:
