@@ -60,6 +60,11 @@ public:
   // Complete constructor for decorations with two word literals
   SPIRVDecorateGeneric(Op OC, SPIRVWord WC, Decoration TheDec,
                        SPIRVEntry *TheTarget, SPIRVWord V1, SPIRVWord V2);
+  // Complete constructor for decorations with three word literals
+  SPIRVDecorateGeneric(Op OC, SPIRVWord WC, Decoration TheDec,
+                       SPIRVEntry *TheTarget, SPIRVWord V1, SPIRVWord V2,
+                       SPIRVWord V3);
+
   // Incomplete constructor
   SPIRVDecorateGeneric(Op OC);
 
@@ -124,6 +129,11 @@ public:
   SPIRVDecorate(Decoration TheDec, SPIRVEntry *TheTarget, SPIRVWord V1,
                 SPIRVWord V2)
       : SPIRVDecorateGeneric(OC, 5, TheDec, TheTarget, V1, V2) {}
+  // Complete constructor for decorations with three word literals
+  SPIRVDecorate(Decoration TheDec, SPIRVEntry *TheTarget, SPIRVWord V1,
+                SPIRVWord V2, SPIRVWord V3)
+      : SPIRVDecorateGeneric(OC, 6, TheDec, TheTarget, V1, V2, V3) {}
+
   // Incomplete constructor
   SPIRVDecorate() : SPIRVDecorateGeneric(OC) {}
 
@@ -178,12 +188,6 @@ public:
     case internal::DecorationInitModeINTEL:
     case internal::DecorationImplementInCSRINTEL:
       return ExtensionID::SPV_INTEL_global_variable_decorations;
-    case DecorationInitModeINTEL:
-    case DecorationImplementInRegisterMapINTEL:
-      return ExtensionID::SPV_INTEL_global_variable_fpga_decorations;
-    case DecorationHostAccessINTEL:
-      return ExtensionID::SPV_INTEL_global_variable_host_access;
-
     case DecorationConduitKernelArgumentINTEL:
     case DecorationRegisterMapKernelArgumentINTEL:
     case DecorationStableKernelArgumentINTEL:
@@ -194,8 +198,9 @@ public:
     case DecorationMMHostInterfaceMaxBurstINTEL:
     case DecorationMMHostInterfaceWaitRequestINTEL:
       return ExtensionID::SPV_INTEL_fpga_argument_interfaces;
-    case DecorationFPMaxErrorDecorationINTEL:
-      return ExtensionID::SPV_INTEL_fp_max_error;
+    case DecorationLatencyControlLabelINTEL:
+    case DecorationLatencyControlConstraintINTEL:
+      return ExtensionID::SPV_INTEL_fpga_latency_control;
     case internal::DecorationCacheControlLoadINTEL:
     case internal::DecorationCacheControlStoreINTEL:
       return ExtensionID::SPV_INTEL_cache_controls;
@@ -369,7 +374,7 @@ public:
   SPIRVDecorationGroup(SPIRVModule *TheModule, SPIRVId TheId)
       : SPIRVEntry(TheModule, WC, OC, TheId) {
     validate();
-  };
+  }
   // Incomplete constructor
   SPIRVDecorationGroup() : SPIRVEntry(OC) {}
   void encodeAll(spv_ostream &O) const override;
@@ -620,12 +625,12 @@ public:
                                          SPIRVWord TargetWidth,
                                          spv::FPRoundingMode FloatControl)
       : SPIRVDecorate(spv::DecorationFunctionRoundingModeINTEL, TheTarget,
-                      TargetWidth, static_cast<SPIRVWord>(FloatControl)){};
+                      TargetWidth, static_cast<SPIRVWord>(FloatControl)) {}
 
-  SPIRVWord getTargetWidth() const { return Literals.at(0); };
+  SPIRVWord getTargetWidth() const { return Literals.at(0); }
   spv::FPRoundingMode getRoundingMode() const {
     return static_cast<spv::FPRoundingMode>(Literals.at(1));
-  };
+  }
 };
 
 class SPIRVDecorateFunctionDenormModeINTEL : public SPIRVDecorate {
@@ -635,12 +640,12 @@ public:
                                        SPIRVWord TargetWidth,
                                        spv::FPDenormMode FloatControl)
       : SPIRVDecorate(spv::DecorationFunctionDenormModeINTEL, TheTarget,
-                      TargetWidth, static_cast<SPIRVWord>(FloatControl)){};
+                      TargetWidth, static_cast<SPIRVWord>(FloatControl)) {}
 
-  SPIRVWord getTargetWidth() const { return Literals.at(0); };
+  SPIRVWord getTargetWidth() const { return Literals.at(0); }
   spv::FPDenormMode getDenormMode() const {
     return static_cast<spv::FPDenormMode>(Literals.at(1));
-  };
+  }
 };
 
 class SPIRVDecorateFunctionFloatingPointModeINTEL : public SPIRVDecorate {
@@ -650,19 +655,19 @@ public:
                                               SPIRVWord TargetWidth,
                                               spv::FPOperationMode FloatControl)
       : SPIRVDecorate(spv::DecorationFunctionFloatingPointModeINTEL, TheTarget,
-                      TargetWidth, static_cast<SPIRVWord>(FloatControl)){};
+                      TargetWidth, static_cast<SPIRVWord>(FloatControl)) {}
 
-  SPIRVWord getTargetWidth() const { return Literals.at(0); };
+  SPIRVWord getTargetWidth() const { return Literals.at(0); }
   spv::FPOperationMode getOperationMode() const {
     return static_cast<spv::FPOperationMode>(Literals.at(1));
-  };
+  }
 };
 
 class SPIRVDecorateStallEnableINTEL : public SPIRVDecorate {
 public:
   // Complete constructor for SPIRVDecorateStallEnableINTEL
   SPIRVDecorateStallEnableINTEL(SPIRVEntry *TheTarget)
-      : SPIRVDecorate(spv::DecorationStallEnableINTEL, TheTarget){};
+      : SPIRVDecorate(spv::DecorationStallEnableINTEL, TheTarget) {}
 };
 
 class SPIRVDecorateFuseLoopsInFunctionINTEL : public SPIRVDecorate {
@@ -671,7 +676,7 @@ public:
   SPIRVDecorateFuseLoopsInFunctionINTEL(SPIRVEntry *TheTarget, SPIRVWord Depth,
                                         SPIRVWord Independent)
       : SPIRVDecorate(spv::DecorationFuseLoopsInFunctionINTEL, TheTarget, Depth,
-                      Independent){};
+                      Independent) {}
 };
 
 class SPIRVDecorateMathOpDSPModeINTEL : public SPIRVDecorate {
@@ -680,21 +685,21 @@ public:
   SPIRVDecorateMathOpDSPModeINTEL(SPIRVEntry *TheTarget, SPIRVWord Mode,
                                   SPIRVWord Propagate)
       : SPIRVDecorate(spv::DecorationMathOpDSPModeINTEL, TheTarget, Mode,
-                      Propagate){};
+                      Propagate) {}
 };
 
 class SPIRVDecorateAliasScopeINTEL : public SPIRVDecorateId {
 public:
   // Complete constructor for SPIRVDecorateAliasScopeINTEL
   SPIRVDecorateAliasScopeINTEL(SPIRVEntry *TheTarget, SPIRVId AliasList)
-      : SPIRVDecorateId(spv::DecorationAliasScopeINTEL, TheTarget, AliasList){};
+      : SPIRVDecorateId(spv::DecorationAliasScopeINTEL, TheTarget, AliasList) {}
 };
 
 class SPIRVDecorateNoAliasINTEL : public SPIRVDecorateId {
 public:
   // Complete constructor for SPIRVDecorateNoAliasINTEL
   SPIRVDecorateNoAliasINTEL(SPIRVEntry *TheTarget, SPIRVId AliasList)
-      : SPIRVDecorateId(spv::DecorationNoAliasINTEL, TheTarget, AliasList){};
+      : SPIRVDecorateId(spv::DecorationNoAliasINTEL, TheTarget, AliasList) {}
 };
 
 class SPIRVDecorateInitiationIntervalINTEL : public SPIRVDecorate {
@@ -702,7 +707,7 @@ public:
   // Complete constructor for SPIRVDecorateInitiationIntervalINTEL
   SPIRVDecorateInitiationIntervalINTEL(SPIRVEntry *TheTarget, SPIRVWord Cycles)
       : SPIRVDecorate(spv::DecorationInitiationIntervalINTEL, TheTarget,
-                      Cycles){};
+                      Cycles) {}
 };
 
 class SPIRVDecorateMaxConcurrencyINTEL : public SPIRVDecorate {
@@ -710,80 +715,33 @@ public:
   // Complete constructor for SPIRVDecorateMaxConcurrencyINTEL
   SPIRVDecorateMaxConcurrencyINTEL(SPIRVEntry *TheTarget, SPIRVWord Invocations)
       : SPIRVDecorate(spv::DecorationMaxConcurrencyINTEL, TheTarget,
-                      Invocations){};
+                      Invocations) {}
 };
 
 class SPIRVDecoratePipelineEnableINTEL : public SPIRVDecorate {
 public:
   // Complete constructor for SPIRVDecoratePipelineEnableINTEL
   SPIRVDecoratePipelineEnableINTEL(SPIRVEntry *TheTarget, SPIRVWord Enable)
-      : SPIRVDecorate(spv::DecorationPipelineEnableINTEL, TheTarget, Enable){};
+      : SPIRVDecorate(spv::DecorationPipelineEnableINTEL, TheTarget, Enable) {}
 };
 
-class SPIRVDecorateHostAccessINTELBase : public SPIRVDecorate {
+class SPIRVDecorateHostAccessINTEL : public SPIRVDecorate {
 public:
   // Complete constructor for SPIRVHostAccessINTEL
-  SPIRVDecorateHostAccessINTELBase(Decoration D, SPIRVEntry *TheTarget,
-                                   HostAccessQualifier AccessMode,
-                                   const std::string &VarName)
-      : SPIRVDecorate(D, TheTarget) {
+  SPIRVDecorateHostAccessINTEL(SPIRVEntry *TheTarget, SPIRVWord AccessMode,
+                               const std::string &VarName)
+      : SPIRVDecorate(spv::internal::DecorationHostAccessINTEL, TheTarget) {
     Literals.push_back(AccessMode);
     for (auto &I : getVec(VarName))
       Literals.push_back(I);
     WordCount += Literals.size();
-  };
+  }
 
   SPIRVWord getAccessMode() const { return Literals.front(); }
   std::string getVarName() const {
     return getString(Literals.cbegin() + 1, Literals.cend());
   }
-};
 
-class SPIRVDecorateHostAccessINTEL : public SPIRVDecorateHostAccessINTELBase {
-public:
-  SPIRVDecorateHostAccessINTEL(SPIRVEntry *TheTarget,
-                               HostAccessQualifier AccessMode,
-                               const std::string &VarName)
-      : SPIRVDecorateHostAccessINTELBase(DecorationHostAccessINTEL, TheTarget,
-                                         AccessMode, VarName) {}
-  static void encodeLiterals(SPIRVEncoder &Encoder,
-                             const std::vector<SPIRVWord> &Literals) {
-#ifdef _SPIRV_SUPPORT_TEXT_FMT
-    if (SPIRVUseTextFormat) {
-      Encoder << (HostAccessQualifier)Literals.front();
-      std::string Name = getString(Literals.cbegin() + 1, Literals.cend());
-      Encoder << Name;
-    } else
-#endif
-      Encoder << Literals;
-  }
-
-  static void decodeLiterals(SPIRVDecoder &Decoder,
-                             std::vector<SPIRVWord> &Literals) {
-#ifdef _SPIRV_SUPPORT_TEXT_FMT
-    if (SPIRVUseTextFormat) {
-      HostAccessQualifier Mode;
-      Decoder >> Mode;
-      std::string Name;
-      Decoder >> Name;
-      Literals.front() = Mode;
-      std::copy_n(getVec(Name).begin(), Literals.size() - 1,
-                  Literals.begin() + 1);
-
-    } else
-#endif
-      Decoder >> Literals;
-  }
-};
-
-class SPIRVDecorateHostAccessINTELLegacy
-    : public SPIRVDecorateHostAccessINTELBase {
-public:
-  SPIRVDecorateHostAccessINTELLegacy(SPIRVEntry *TheTarget,
-                                     HostAccessQualifier AccessMode,
-                                     const std::string &VarName)
-      : SPIRVDecorateHostAccessINTELBase(internal::DecorationHostAccessINTEL,
-                                         TheTarget, AccessMode, VarName) {}
   static void encodeLiterals(SPIRVEncoder &Encoder,
                              const std::vector<SPIRVWord> &Literals) {
 #ifdef _SPIRV_SUPPORT_TEXT_FMT
@@ -814,75 +772,12 @@ public:
   }
 };
 
-class SPIRVDecorateInitModeINTELBase : public SPIRVDecorate {
+class SPIRVDecorateInitModeINTEL : public SPIRVDecorate {
 public:
   // Complete constructor for SPIRVInitModeINTEL
-  SPIRVDecorateInitModeINTELBase(Decoration D, SPIRVEntry *TheTarget,
-                                 InitializationModeQualifier Trigger)
-      : SPIRVDecorate(D, TheTarget) {
-    Literals.push_back(Trigger);
-    WordCount += Literals.size();
-  }
-};
-
-class SPIRVDecorateInitModeINTEL : public SPIRVDecorateInitModeINTELBase {
-public:
-  SPIRVDecorateInitModeINTEL(SPIRVEntry *TheTarget,
-                             InitializationModeQualifier Trigger)
-      : SPIRVDecorateInitModeINTELBase(DecorationInitModeINTEL, TheTarget,
-                                       Trigger) {}
-
-  static void encodeLiterals(SPIRVEncoder &Encoder,
-                             const std::vector<SPIRVWord> &Literals) {
-#ifdef _SPIRV_SUPPORT_TEXT_FMT
-    if (SPIRVUseTextFormat) {
-      Encoder << (InitializationModeQualifier)Literals.back();
-    } else
-#endif
-      Encoder << Literals;
-  }
-
-  static void decodeLiterals(SPIRVDecoder &Decoder,
-                             std::vector<SPIRVWord> &Literals) {
-#ifdef _SPIRV_SUPPORT_TEXT_FMT
-    if (SPIRVUseTextFormat) {
-      InitializationModeQualifier Q;
-      Decoder >> Q;
-      Literals.back() = Q;
-    } else
-#endif
-      Decoder >> Literals;
-  }
-};
-
-class SPIRVDecorateInitModeINTELLegacy : public SPIRVDecorateInitModeINTELBase {
-public:
-  SPIRVDecorateInitModeINTELLegacy(SPIRVEntry *TheTarget,
-                                   InitializationModeQualifier Trigger)
-      : SPIRVDecorateInitModeINTELBase(internal::DecorationInitModeINTEL,
-                                       TheTarget, Trigger) {}
-
-  static void encodeLiterals(SPIRVEncoder &Encoder,
-                             const std::vector<SPIRVWord> &Literals) {
-#ifdef _SPIRV_SUPPORT_TEXT_FMT
-    if (SPIRVUseTextFormat) {
-      Encoder << Literals.back();
-    } else
-#endif
-      Encoder << Literals;
-  }
-
-  static void decodeLiterals(SPIRVDecoder &Decoder,
-                             std::vector<SPIRVWord> &Literals) {
-#ifdef _SPIRV_SUPPORT_TEXT_FMT
-    if (SPIRVUseTextFormat) {
-      SPIRVWord Q;
-      Decoder >> Q;
-      Literals.back() = Q;
-    } else
-#endif
-      Decoder >> Literals;
-  }
+  SPIRVDecorateInitModeINTEL(SPIRVEntry *TheTarget, SPIRVWord Trigger)
+      : SPIRVDecorate(spv::internal::DecorationInitModeINTEL, TheTarget,
+                      Trigger) {}
 };
 
 class SPIRVDecorateImplementInCSRINTEL : public SPIRVDecorate {
@@ -893,15 +788,6 @@ public:
                       Value) {}
 };
 
-class SPIRVDecorateImplementInRegisterMapINTEL : public SPIRVDecorate {
-public:
-  // Complete constructor for SPIRVImplementInCSRINTEL
-  SPIRVDecorateImplementInRegisterMapINTEL(SPIRVEntry *TheTarget,
-                                           SPIRVWord Value)
-      : SPIRVDecorate(DecorationImplementInRegisterMapINTEL, TheTarget, Value) {
-  }
-};
-
 class SPIRVDecorateCacheControlLoadINTEL : public SPIRVDecorate {
 public:
   // Complete constructor for SPIRVDecorateCacheControlLoadINTEL
