@@ -380,16 +380,6 @@ void SPIRVEntry::takeAnnotations(SPIRVForward *E) {
     static_cast<SPIRVFunction *>(this)->takeExecutionModes(E);
 }
 
-void SPIRVEntry::replaceTargetIdInDecorates(SPIRVId Id) {
-  for (auto It = Decorates.begin(), E = Decorates.end(); It != E; ++It)
-    const_cast<SPIRVDecorate *>(It->second)->setTargetId(Id);
-  for (auto It = DecorateIds.begin(), E = DecorateIds.end(); It != E; ++It)
-    const_cast<SPIRVDecorateId *>(It->second)->setTargetId(Id);
-  for (auto It = MemberDecorates.begin(), E = MemberDecorates.end(); It != E;
-       ++It)
-    const_cast<SPIRVMemberDecorate *>(It->second)->setTargetId(Id);
-}
-
 // Check if an entry has Kind of decoration and get the literal of the
 // first decoration of such kind at Index.
 bool SPIRVEntry::hasDecorate(Decoration Kind, size_t Index,
@@ -622,7 +612,7 @@ SPIRVEntryPoint::SPIRVEntryPoint(SPIRVModule *TheModule,
                                  SPIRVExecutionModelKind TheExecModel,
                                  SPIRVId TheId, const std::string &TheName,
                                  std::vector<SPIRVId> Variables)
-    : SPIRVAnnotation(OpEntryPoint, TheModule->get<SPIRVFunction>(TheId),
+    : SPIRVAnnotation(TheModule->get<SPIRVFunction>(TheId),
                       getSizeInWords(TheName) + Variables.size() + 3),
       ExecModel(TheExecModel), Name(TheName), Variables(Variables) {}
 
@@ -646,9 +636,7 @@ void SPIRVExecutionMode::decode(std::istream &I) {
   getDecoder(I) >> Target >> ExecMode;
   switch (static_cast<uint32_t>(ExecMode)) {
   case ExecutionModeLocalSize:
-  case ExecutionModeLocalSizeId:
   case ExecutionModeLocalSizeHint:
-  case ExecutionModeLocalSizeHintId:
   case ExecutionModeMaxWorkgroupSizeINTEL:
     WordLiterals.resize(3);
     break;
@@ -667,16 +655,11 @@ void SPIRVExecutionMode::decode(std::istream &I) {
   case ExecutionModeSharedLocalMemorySizeINTEL:
   case ExecutionModeNamedBarrierCountINTEL:
   case ExecutionModeSubgroupSize:
-  case ExecutionModeSubgroupsPerWorkgroup:
-  case ExecutionModeSubgroupsPerWorkgroupId:
   case ExecutionModeMaxWorkDimINTEL:
   case ExecutionModeNumSIMDWorkitemsINTEL:
   case ExecutionModeSchedulerTargetFmaxMhzINTEL:
   case ExecutionModeRegisterMapInterfaceINTEL:
   case ExecutionModeStreamingInterfaceINTEL:
-  case ExecutionModeMaximumRegistersINTEL:
-  case ExecutionModeMaximumRegistersIdINTEL:
-  case ExecutionModeNamedMaximumRegistersINTEL:
     WordLiterals.resize(1);
     break;
   default:
@@ -698,8 +681,7 @@ SPIRVForward *SPIRVAnnotationGeneric::getOrCreateTarget() const {
 }
 
 SPIRVName::SPIRVName(const SPIRVEntry *TheTarget, const std::string &TheStr)
-    : SPIRVAnnotation(OpName, TheTarget, getSizeInWords(TheStr) + 2),
-      Str(TheStr) {}
+    : SPIRVAnnotation(TheTarget, getSizeInWords(TheStr) + 2), Str(TheStr) {}
 
 void SPIRVName::encode(spv_ostream &O) const { getEncoder(O) << Target << Str; }
 
