@@ -71,10 +71,8 @@ inline bool isValid(spv::ExecutionModel V) {
   case ExecutionModelClosestHitKHR:
   case ExecutionModelMissKHR:
   case ExecutionModelCallableKHR:
+  case ExecutionModeRegisterMapInterfaceINTEL:
   case ExecutionModeStreamingInterfaceINTEL:
-  case internal::ExecutionModeMaximumRegistersINTEL:
-  case internal::ExecutionModeMaximumRegistersIdINTEL:
-  case internal::ExecutionModeNamedMaximumRegistersINTEL:
     return true;
   default:
     return false;
