@@ -58,44 +58,6 @@
 
 namespace SPIRV {
 
-namespace {
-std::string to_string(uint32_t Version) {
-  std::string Res;
-  switch (Version) {
-  case static_cast<uint32_t>(VersionNumber::SPIRV_1_0):
-    Res = "1.0";
-    break;
-  case static_cast<uint32_t>(VersionNumber::SPIRV_1_1):
-    Res = "1.1";
-    break;
-  case static_cast<uint32_t>(VersionNumber::SPIRV_1_2):
-    Res = "1.2";
-    break;
-  case static_cast<uint32_t>(VersionNumber::SPIRV_1_3):
-    Res = "1.3";
-    break;
-  case static_cast<uint32_t>(VersionNumber::SPIRV_1_4):
-    Res = "1.4";
-    break;
-  case static_cast<uint32_t>(VersionNumber::SPIRV_1_5):
-    Res = "1.5";
-    break;
-  case static_cast<uint32_t>(VersionNumber::SPIRV_1_6):
-    Res = "1.6";
-    break;
-  default:
-    Res = "unknown";
-  }
-
-  Res += " (" + std::to_string(Version) + ")";
-  return Res;
-}
-
-std::string to_string(VersionNumber Version) {
-  return to_string(static_cast<uint32_t>(Version));
-}
-} // Anonymous namespace
-
 SPIRVModule::SPIRVModule()
     : AutoAddCapability(true), ValidateCapability(false), IsValid(true) {}
 
@@ -168,13 +130,6 @@ public:
   SPIRVConstant *getLiteralAsConstant(unsigned Literal) override;
   unsigned getNumFunctions() const override { return FuncVec.size(); }
   unsigned getNumVariables() const override { return VariableVec.size(); }
-  std::vector<SPIRVValue *> getFunctionPointers() const override {
-    std::vector<SPIRVValue *> Res;
-    for (auto *C : ConstVec)
-      if (C->getOpCode() == OpConstantFunctionPointerINTEL)
-        Res.emplace_back(C);
-    return Res;
-  }
   SourceLanguage getSourceLanguage(SPIRVWord *Ver = nullptr) const override {
     if (Ver)
       *Ver = SrcLangVer;
@@ -217,16 +172,7 @@ public:
   void insertEntryNoId(SPIRVEntry *Entry) override { EntryNoId.insert(Entry); }
 
   void setSPIRVVersion(SPIRVWord Ver) override {
-    if (!this->isAllowedToUseVersion(static_cast<VersionNumber>(Ver))) {
-      std::stringstream SS;
-      SS << "SPIR-V version was restricted to at most "
-         << to_string(getMaximumAllowedSPIRVVersion())
-         << " but a construct from the input requires SPIR-V version "
-         << to_string(Ver) << " or above\n";
-      getErrorLog().checkError(false, SPIRVEC_RequiresVersion, SS.str());
-      setInvalid();
-      return;
-    }
+    assert(this->isAllowedToUseVersion(static_cast<VersionNumber>(Ver)));
     SPIRVVersion = Ver;
   }
 
@@ -279,8 +225,7 @@ public:
   template <class T> T *addType(T *Ty);
   SPIRVTypeArray *addArrayType(SPIRVType *, SPIRVConstant *) override;
   SPIRVTypeBool *addBoolType() override;
-  SPIRVTypeFloat *addFloatType(unsigned BitWidth,
-                               unsigned FloatingPointEncoding) override;
+  SPIRVTypeFloat *addFloatType(unsigned BitWidth) override;
   SPIRVTypeFunction *addFunctionType(SPIRVType *,
                                      const std::vector<SPIRVType *> &) override;
   SPIRVTypeInt *addIntegerType(unsigned BitWidth) override;
@@ -301,9 +246,6 @@ public:
   addJointMatrixINTELType(SPIRVType *, std::vector<SPIRVValue *>) override;
   SPIRVTypeCooperativeMatrixKHR *
   addCooperativeMatrixKHRType(SPIRVType *, std::vector<SPIRVValue *>) override;
-  SPIRVInstruction *
-  addCooperativeMatrixLengthKHRInst(SPIRVType *, SPIRVType *,
-                                    SPIRVBasicBlock *) override;
   SPIRVType *addOpaqueGenericType(Op) override;
   SPIRVTypeDeviceEvent *addDeviceEventType() override;
   SPIRVTypeQueue *addQueueType() override;
@@ -592,8 +534,6 @@ private:
   SPIRVCapMap CapMap;
   SPIRVUnknownStructFieldMap UnknownStructFieldMap;
   std::map<unsigned, SPIRVTypeInt *> IntTypeMap;
-  SmallDenseMap<std::pair<unsigned, unsigned>, SPIRVTypeFloat *, 4>
-      FloatTypeMap;
   std::map<unsigned, SPIRVConstant *> LiteralMap;
   std::vector<SPIRVExtInst *> DebugInstVec;
   std::vector<SPIRVExtInst *> AuxDataInstVec;
@@ -715,17 +655,6 @@ void SPIRVModuleImpl::addExtension(ExtensionID Ext) {
     return;
   }
   SPIRVExt.insert(ExtName);
-
-  // SPV_EXT_shader_atomic_float16_add extends the
-  // SPV_EXT_shader_atomic_float_add extension.
-  // The specification requires both extensions to be added to use
-  // AtomicFloat16AddEXT capability whereas getRequiredExtension()
-  // is able to return a single extensionID.
-  if (Ext == ExtensionID::SPV_EXT_shader_atomic_float16_add) {
-    SPIRVMap<ExtensionID, std::string>::find(
-        ExtensionID::SPV_EXT_shader_atomic_float_add, &ExtName);
-    SPIRVExt.insert(ExtName);
-  }
 }
 
 void SPIRVModuleImpl::addCapability(SPIRVCapabilityKind Cap) {
@@ -1007,15 +936,9 @@ SPIRVTypeInt *SPIRVModuleImpl::addIntegerType(unsigned BitWidth) {
   return addType(Ty);
 }
 
-SPIRVTypeFloat *SPIRVModuleImpl::addFloatType(unsigned BitWidth,
-                                              unsigned FloatingPointEncoding) {
-  auto Desc = std::make_pair(BitWidth, FloatingPointEncoding);
-  auto Loc = FloatTypeMap.find(Desc);
-  if (Loc != FloatTypeMap.end())
-    return Loc->second;
-  auto *Ty = new SPIRVTypeFloat(this, getId(), BitWidth, FloatingPointEncoding);
-  FloatTypeMap[Desc] = Ty;
-  return addType(Ty);
+SPIRVTypeFloat *SPIRVModuleImpl::addFloatType(unsigned BitWidth) {
+  SPIRVTypeFloat *T = addType(new SPIRVTypeFloat(this, getId(), BitWidth));
+  return T;
 }
 
 SPIRVTypePointer *
@@ -1068,14 +991,6 @@ SPIRVModuleImpl::addCooperativeMatrixKHRType(SPIRVType *CompType,
       new SPIRVTypeCooperativeMatrixKHR(this, getId(), CompType, Args));
 }
 
-SPIRVInstruction *SPIRVModuleImpl::addCooperativeMatrixLengthKHRInst(
-    SPIRVType *RetTy, SPIRVType *MatTy, SPIRVBasicBlock *BB) {
-  return addInstruction(
-      SPIRVInstTemplateBase::create(OpCooperativeMatrixLengthKHR, RetTy,
-                                    getId(), getVec(MatTy->getId()), BB, this),
-      BB);
-}
-
 SPIRVType *SPIRVModuleImpl::addOpaqueGenericType(Op TheOpCode) {
   return addType(new SPIRVTypeOpaqueGeneric(TheOpCode, this, getId()));
 }
@@ -1190,19 +1105,17 @@ SPIRVEntry *SPIRVModuleImpl::replaceForward(SPIRVForward *Forward,
                                             SPIRVEntry *Entry) {
   SPIRVId Id = Entry->getId();
   SPIRVId ForwardId = Forward->getId();
-  if (ForwardId == Id) {
+  if (ForwardId == Id)
     IdEntryMap[Id] = Entry;
-    // Annotations include name, decorations, execution modes
-    Entry->takeAnnotations(Forward);
-  } else {
+  else {
     auto Loc = IdEntryMap.find(Id);
     assert(Loc != IdEntryMap.end());
     IdEntryMap.erase(Loc);
     Entry->setId(ForwardId);
     IdEntryMap[ForwardId] = Entry;
-    // Replace current Id with ForwardId in decorates.
-    Entry->replaceTargetIdInDecorates(ForwardId);
   }
+  // Annotations include name, decorations, execution modes
+  Entry->takeAnnotations(Forward);
   delete Forward;
   return Entry;
 }
@@ -2145,6 +2058,36 @@ void SPIRVModuleImpl::addUnknownStructField(SPIRVTypeStruct *Struct, unsigned I,
   UnknownStructFieldMap[Struct].push_back(std::make_pair(I, ID));
 }
 
+static std::string to_string(uint32_t Version) {
+  std::string Res;
+  switch (Version) {
+  case static_cast<uint32_t>(VersionNumber::SPIRV_1_0):
+    Res = "1.0";
+    break;
+  case static_cast<uint32_t>(VersionNumber::SPIRV_1_1):
+    Res = "1.1";
+    break;
+  case static_cast<uint32_t>(VersionNumber::SPIRV_1_2):
+    Res = "1.2";
+    break;
+  case static_cast<uint32_t>(VersionNumber::SPIRV_1_3):
+    Res = "1.3";
+    break;
+  case static_cast<uint32_t>(VersionNumber::SPIRV_1_4):
+    Res = "1.4";
+    break;
+  default:
+    Res = "unknown";
+  }
+
+  Res += " (" + std::to_string(Version) + ")";
+  return Res;
+}
+
+static std::string to_string(VersionNumber Version) {
+  return to_string(static_cast<uint32_t>(Version));
+}
+
 std::istream &operator>>(std::istream &I, SPIRVModule &M) {
   SPIRVDecoder Decoder(I, M);
   SPIRVModuleImpl &MI = *static_cast<SPIRVModuleImpl *>(&M);
@@ -2161,7 +2104,9 @@ std::istream &operator>>(std::istream &I, SPIRVModule &M) {
   }
 
   Decoder >> MI.SPIRVVersion;
-  bool SPIRVVersionIsKnown = isSPIRVVersionKnown(MI.SPIRVVersion);
+  bool SPIRVVersionIsKnown =
+      static_cast<uint32_t>(VersionNumber::MinimumVersion) <= MI.SPIRVVersion &&
+      MI.SPIRVVersion <= static_cast<uint32_t>(VersionNumber::MaximumVersion);
   if (!M.getErrorLog().checkError(
           SPIRVVersionIsKnown, SPIRVEC_InvalidModule,
           "unsupported SPIR-V version number '" + to_string(MI.SPIRVVersion) +
