@@ -198,22 +198,16 @@ template <> inline void SPIRVMap<Decoration, std::string>::init() {
   add(DecorationStableKernelArgumentINTEL, "StableKernelArgumentINTEL");
   add(DecorationLatencyControlLabelINTEL, "LatencyControlLabelINTEL");
   add(DecorationLatencyControlConstraintINTEL, "LatencyControlConstraintINTEL");
-  add(DecorationFPMaxErrorDecorationINTEL, "FPMaxErrorDecorationINTEL");
-
-  add(DecorationHostAccessINTEL, "HostAccessINTEL");
-  add(DecorationInitModeINTEL, "InitModeINTEL");
-  add(DecorationImplementInRegisterMapINTEL, "ImplementInRegisterMapINTEL");
-
-  add(DecorationCacheControlLoadINTEL, "CacheControlLoadINTEL");
-  add(DecorationCacheControlStoreINTEL, "CacheControlStoreINTEL");
-  add(DecorationConditionalINTEL, "DecorationConditionalINTEL");
 
   // From spirv_internal.hpp
+  add(internal::DecorationCallableFunctionINTEL, "CallableFunctionINTEL");
   add(internal::DecorationRuntimeAlignedINTEL, "RuntimeAlignedINTEL");
   add(internal::DecorationHostAccessINTEL, "HostAccessINTEL");
   add(internal::DecorationInitModeINTEL, "InitModeINTEL");
   add(internal::DecorationImplementInCSRINTEL, "ImplementInCSRINTEL");
   add(internal::DecorationArgumentAttributeINTEL, "ArgumentAttributeINTEL");
+  add(internal::DecorationCacheControlLoadINTEL, "CacheControlLoadINTEL");
+  add(internal::DecorationCacheControlStoreINTEL, "CacheControlStoreINTEL");
 
   add(DecorationMax, "Max");
 }
@@ -616,14 +610,11 @@ template <> inline void SPIRVMap<Capability, std::string>::init() {
   add(CapabilityGroupNonUniformRotateKHR, "GroupNonUniformRotateKHR");
   add(CapabilityAtomicFloat32AddEXT, "AtomicFloat32AddEXT");
   add(CapabilityAtomicFloat64AddEXT, "AtomicFloat64AddEXT");
-  add(CapabilityLongCompositesINTEL, "LongCompositesINTEL");
-  add(CapabilityOptNoneEXT, "OptNoneEXT");
+  add(CapabilityLongConstantCompositeINTEL, "LongConstantCompositeINTEL");
+  add(CapabilityOptNoneINTEL, "OptNoneINTEL");
   add(CapabilityAtomicFloat16AddEXT, "AtomicFloat16AddEXT");
   add(CapabilityDebugInfoModuleINTEL, "DebugInfoModuleINTEL");
   add(CapabilitySplitBarrierINTEL, "SplitBarrierINTEL");
-  add(CapabilityGlobalVariableFPGADecorationsINTEL,
-      "GlobalVariableFPGADecorationsINTEL");
-  add(CapabilityGlobalVariableHostAccessINTEL, "GlobalVariableHostAccessINTEL");
   add(CapabilityGroupUniformArithmeticKHR, "GroupUniformArithmeticKHR");
   add(CapabilityFPGADSPControlINTEL, "FPGADSPControlINTEL");
   add(CapabilityFPGAInvocationPipeliningAttributesINTEL,
@@ -632,21 +623,11 @@ template <> inline void SPIRVMap<Capability, std::string>::init() {
   add(CapabilityMax, "Max");
   add(CapabilityFPGAArgumentInterfacesINTEL, "FPGAArgumentInterfacesINTEL");
   add(CapabilityFPGALatencyControlINTEL, "FPGALatencyControlINTEL");
-  add(CapabilityFPMaxErrorINTEL, "FPMaxErrorINTEL");
-  add(CapabilityRegisterLimitsINTEL, "RegisterLimitsINTEL");
-  add(CapabilityBFloat16TypeKHR, "BFloat16TypeKHR");
-  add(CapabilityBFloat16DotProductKHR, "BFloat16DotProductKHR");
-  add(CapabilityBFloat16CooperativeMatrixKHR, "BFloat16CooperativeMatrixKHR");
-  add(CapabilityArithmeticFenceEXT, "ArithmeticFenceEXT");
-  add(CapabilitySubgroup2DBlockIOINTEL, "Subgroup2DBlockIOINTEL");
-  add(CapabilitySubgroup2DBlockTransformINTEL, "Subgroup2DBlockTransformINTEL");
-  add(CapabilitySubgroup2DBlockTransposeINTEL, "Subgroup2DBlockTransposeINTEL");
-  add(CapabilitySubgroupMatrixMultiplyAccumulateINTEL,
-      "SubgroupMatrixMultiplyAccumulateINTEL");
-  add(CapabilityTernaryBitwiseFunctionINTEL, "TernaryBitwiseFunctionINTEL");
-  add(CapabilityFMAKHR, "FMAKHR");
   // From spirv_internal.hpp
+  add(internal::CapabilityFastCompositeINTEL, "FastCompositeINTEL");
+  add(internal::CapabilityOptNoneINTEL, "OptNoneINTEL");
   add(internal::CapabilityTokenTypeINTEL, "TokenTypeINTEL");
+  add(internal::CapabilityFPArithmeticFenceINTEL, "FPArithmeticFenceINTEL");
   add(internal::CapabilityBfloat16ConversionINTEL, "Bfloat16ConversionINTEL");
   add(internal::CapabilityJointMatrixINTEL, "JointMatrixINTEL");
   add(internal::CapabilityHWThreadQueryINTEL, "HWThreadQueryINTEL");
@@ -667,62 +648,9 @@ template <> inline void SPIRVMap<Capability, std::string>::init() {
   add(internal::CapabilityJointMatrixPackedInt4ComponentTypeINTEL,
       "JointMatrixPackedInt4ComponentTypeINTEL");
   add(internal::CapabilityCacheControlsINTEL, "CacheControlsINTEL");
-  add(internal::CapabilityCooperativeMatrixPrefetchINTEL,
-      "CooperativeMatrixPrefetchINTEL");
-  add(internal::CapabilityCooperativeMatrixCheckedInstructionsINTEL,
-      "CooperativeMatrixCheckedInstructionsINTEL");
-  add(internal::CapabilityBindlessImagesINTEL, "BindlessImagesINTEL");
-  add(CapabilityInt4TypeINTEL, "Int4TypeINTEL");
-  add(CapabilityInt4CooperativeMatrixINTEL, "Int4CooperativeMatrixINTEL");
-  add(CapabilityFunctionVariantsINTEL, "FunctionVariantsINTEL");
-  add(CapabilitySpecConditionalINTEL, "SpecConditionalINTEL");
-  add(internal::CapabilityBFloat16ArithmeticINTEL, "BFloat16ArithmeticINTEL");
-  add(CapabilityFloat8EXT, "Float8EXT");
-  add(CapabilityFloat8CooperativeMatrixEXT, "Float8CooperativeMatrixEXT");
-  add(internal::CapabilityPredicatedIOINTEL, "PredicatedIOINTEL");
-  add(internal::CapabilitySigmoidINTEL, "SigmoidINTEL");
-  add(internal::CapabilityAtomicBFloat16AddINTEL, "AtomicBFloat16AddINTEL");
-  add(internal::CapabilityAtomicBFloat16MinMaxINTEL,
-      "AtomicBFloat16MinMaxINTEL");
-  add(internal::CapabilityAtomicInt16CompareExchangeINTEL,
-      "AtomicInt16CompareExchangeINTEL");
-  add(internal::CapabilityInt16AtomicsINTEL, "Int16AtomicsINTEL");
-  add(internal::CapabilityAtomicBFloat16LoadStoreINTEL,
-      "AtomicBFloat16LoadStoreINTEL");
-  add(internal::CapabilityFloat4E2M1INTEL, "Float4E2M1INTEL");
-  add(internal::CapabilityFloat4E2M1CooperativeMatrixINTEL,
-      "Float4E2M1CooperativeMatrixINTEL");
-  add(internal::CapabilityFloatConversionsINTEL, "FloatConversionsINTEL");
 }
 SPIRV_DEF_NAMEMAP(Capability, SPIRVCapabilityNameMap)
 
-template <>
-inline void SPIRVMap<InitializationModeQualifier, std::string>::init() {
-  add(InitializationModeQualifierInitOnDeviceReprogramINTEL,
-      "InitOnDeviceReprogramINTEL");
-  add(InitializationModeQualifierInitOnDeviceResetINTEL,
-      "InitOnDeviceResetINTEL");
-  add(InitializationModeQualifierMax, "Max");
-}
-SPIRV_DEF_NAMEMAP(InitializationModeQualifier,
-                  SPIRVInitializationModeQualifierNameMap)
-
-template <> inline void SPIRVMap<HostAccessQualifier, std::string>::init() {
-  add(HostAccessQualifierNoneINTEL, "NoneINTEL");
-  add(HostAccessQualifierReadINTEL, "ReadINTEL");
-  add(HostAccessQualifierWriteINTEL, "WriteINTEL");
-  add(HostAccessQualifierReadWriteINTEL, "ReadWriteINTEL");
-  add(HostAccessQualifierMax, "Max");
-}
-SPIRV_DEF_NAMEMAP(HostAccessQualifier, SPIRVHostAccessQualifierNameMap)
-
-template <>
-inline void SPIRVMap<NamedMaximumNumberOfRegisters, std::string>::init() {
-  add(NamedMaximumNumberOfRegistersAutoINTEL, "AutoINTEL");
-}
-SPIRV_DEF_NAMEMAP(NamedMaximumNumberOfRegisters,
-                  SPIRVNamedMaximumNumberOfRegistersNameMap);
-
 } /* namespace SPIRV */
 
 #endif // SPIRV_LIBSPIRV_SPIRVNAMEMAPENUM_H
