@@ -125,13 +125,13 @@ public:
     return Type->getRequiredCapability();
   }
 
-  llvm::Optional<ExtensionID> getRequiredExtension() const override {
-    llvm::Optional<ExtensionID> EV;
+  std::optional<ExtensionID> getRequiredExtension() const override {
+    std::optional<ExtensionID> EV;
     if (!hasType())
       return EV;
     EV = Type->getRequiredExtension();
     assert(Module &&
-           (!EV.hasValue() || Module->isAllowedToUseExtension(EV.getValue())));
+           (!EV.has_value() || Module->isAllowedToUseExtension(EV.value())));
     return EV;
   }
 
