@@ -111,9 +111,7 @@ static cl::opt<VersionNumber> MaxSPIRVVersion(
                clEnumValN(VersionNumber::SPIRV_1_1, "1.1", "SPIR-V 1.1"),
                clEnumValN(VersionNumber::SPIRV_1_2, "1.2", "SPIR-V 1.2"),
                clEnumValN(VersionNumber::SPIRV_1_3, "1.3", "SPIR-V 1.3"),
-               clEnumValN(VersionNumber::SPIRV_1_4, "1.4", "SPIR-V 1.4"),
-               clEnumValN(VersionNumber::SPIRV_1_5, "1.5", "SPIR-V 1.5"),
-               clEnumValN(VersionNumber::SPIRV_1_6, "1.6", "SPIR-V 1.6")),
+               clEnumValN(VersionNumber::SPIRV_1_4, "1.4", "SPIR-V 1.4")),
     cl::init(VersionNumber::MaximumVersion));
 
 static cl::list<std::string>
@@ -162,10 +160,6 @@ static cl::opt<bool>
                                 "for the translation from SPIR-V."),
                        cl::Hidden);
 
-static cl::opt<bool> SPIRVEmitFunctionPtrAddrSpace(
-    "spirv-emit-function-ptr-addr-space", cl::init(false),
-    cl::desc("Emit and consume CodeSectionINTEL for function pointers"));
-
 using SPIRV::ExtensionID;
 
 #ifdef _SPIRV_SUPPORT_TEXT_FMT
@@ -208,12 +202,6 @@ static cl::opt<bool> SpecConstInfo(
     cl::desc("Display id of constants available for specializaion and their "
              "size in bytes"));
 
-static cl::opt<bool>
-    SPIRVPrintReport("spirv-print-report", cl::init(false),
-                     cl::desc("Display general information about the module "
-                              "(capabilities, extensions, version, memory model"
-                              " and addressing model)"));
-
 static cl::opt<SPIRV::FPContractMode> FPCMode(
     "spirv-fp-contract", cl::desc("Set FP Contraction mode:"),
     cl::init(SPIRV::FPContractMode::On),
@@ -800,9 +788,6 @@ int main(int Ac, char **Av) {
   if (PreserveOCLKernelArgTypeMetadataThroughString.getNumOccurrences() != 0)
     Opts.setPreserveOCLKernelArgTypeMetadataThroughString(true);
 
-  if (SPIRVEmitFunctionPtrAddrSpace.getNumOccurrences() != 0)
-    Opts.setEmitFunctionPtrAddrSpace(true);
-
 #ifdef _SPIRV_SUPPORT_TEXT_FMT
   if (ToText && (ToBinary || IsReverse || IsRegularization)) {
     errs() << "Cannot use -to-text with -to-binary, -r, -s\n";
@@ -818,7 +803,7 @@ int main(int Ac, char **Av) {
     return convertSPIRV();
 #endif
 
-  if (!IsReverse && !IsRegularization && !SpecConstInfo && !SPIRVPrintReport)
+  if (!IsReverse && !IsRegularization && !SpecConstInfo)
     return convertLLVMToSPIRV(Opts);
 
   if (IsReverse && IsRegularization) {
@@ -845,39 +830,5 @@ int main(int Ac, char **Av) {
                 << ", size in bytes = " << SpecConst.Size
                 << ", type = " << SpecConst.Type << "\n";
   }
-
-  if (SPIRVPrintReport) {
-    std::ifstream IFS(InputFile, std::ios::binary);
-    int ErrCode = 0;
-    std::optional<SPIRV::SPIRVModuleReport> BinReport =
-        SPIRV::getSpirvReport(IFS, ErrCode);
-    if (!BinReport) {
-      std::cerr << "Invalid SPIR-V binary, error code is " << ErrCode << "\n";
-      return -1;
-    }
-
-    SPIRV::SPIRVModuleTextReport TextReport =
-        SPIRV::formatSpirvReport(BinReport.value());
-
-    std::cout << "SPIR-V module report:"
-              << "\n Version: " << TextReport.Version
-              << "\n Memory model: " << TextReport.MemoryModel
-              << "\n Addressing model: " << TextReport.AddrModel << "\n";
-
-    std::cout << " Number of capabilities: " << TextReport.Capabilities.size()
-              << "\n";
-    for (auto &Capability : TextReport.Capabilities)
-      std::cout << "  Capability: " << Capability << "\n";
-
-    std::cout << " Number of extensions: " << TextReport.Extensions.size()
-              << "\n";
-    for (auto &Extension : TextReport.Extensions)
-      std::cout << "  Extension: " << Extension << "\n";
-
-    std::cout << " Number of extended instruction sets: "
-              << TextReport.ExtendedInstructionSets.size() << "\n";
-    for (auto &ExtendedInstructionSet : TextReport.ExtendedInstructionSets)
-      std::cout << "  Extended Instruction Set: " << ExtendedInstructionSet << "\n";
-  }
   return 0;
 }
